#!/bin/ksh
#
# script function
# 
# defines the RTTOV identification numbers 
# for input platform and instrument names
# input names:
# platform is $1
# instrument is $2
#
# output are the variables
#   ${PLATFORM_N}   pltaform number
#   ${INST_N}       instrument number 
#   ${SENSOR_TYPE}  sensor type (ir, mw, hi)
#
# P. Brunel Feb 2003
#
# for the use of this script function the user shall 
# enter the following line (with the dot) before any reference to th function:
#. rttov_id.ksh
#
# example of call to the function is:
# rttov_id eos airs

function rttov_id {
  PLATFORM=$1
  INST=$2

  case ${PLATFORM} in
    'noaa')     PLATFORM_N=1;;
    'dmsp')     PLATFORM_N=2;;
    'meteosat') PLATFORM_N=3;;
    'goes')     PLATFORM_N=4;;
    'gms')      PLATFORM_N=5;;
    'fy2')      PLATFORM_N=6;;
    'trmm')     PLATFORM_N=7;;
    'ers')      PLATFORM_N=8;;
    'eos')      PLATFORM_N=9;;
    'metop')    PLATFORM_N=10;;
    'envisat')  PLATFORM_N=11;;
    'msg')      PLATFORM_N=12;;
    'fy1')      PLATFORM_N=13;;
    'adeos')    PLATFORM_N=14;;
    'mtsat')    PLATFORM_N=15;;
    'coriolis') PLATFORM_N=16;;
    'jpss')     PLATFORM_N=17;;
    'gifts')    PLATFORM_N=18;;
    'xxxxx')    PLATFORM_N=19;;
    'meghatr')  PLATFORM_N=20;;
    'kalpana')  PLATFORM_N=21;;
    'insat_3d') PLATFORM_N=22;;
    'fy3')      PLATFORM_N=23;;
    'coms')     PLATFORM_N=24;;
    'meteor-m') PLATFORM_N=25;;
    'gosat')    PLATFORM_N=26;;
    'calipso')  PLATFORM_N=27;;
    *)          PLATFORM_N=-1;;
  esac

  case ${INST} in
    'hirs')   INST_N=0;;
    'msu')    INST_N=1;;
    'ssu')    INST_N=2;;
    'amsu-a'|'amsua') INST_N=3;;
    'amsu-b'|'amsub') INST_N=4;;
    'avhrr')  INST_N=5;;
    'ssmi')   INST_N=6;;
    'vtpr1')  INST_N=7;;
    'vtpr2')  INST_N=8;;
    'tmi')    INST_N=9;;
    'ssmis')  INST_N=10;;
    'airs')   INST_N=11;;
    'hsb')    INST_N=12;;
    'modis')  INST_N=13;;
    'atsr' | 'aatsr')   INST_N=14;;
    'mhs')    INST_N=15;;
    'iasi')   INST_N=16;;
    'amsr')   INST_N=17;;
    'atms')   INST_N=19;;
    'mviri')  INST_N=20;;
    'seviri') INST_N=21;;
    'imager') case ${PLATFORM} in
      'goes')  INST_N=22;;
      'gms')   INST_N=24;;
      'mtsat') INST_N=24;;
      *)       INST_N=-1;;
      esac;;
    'sounder')INST_N=23;;
    'vissr')  INST_N=25;;
    'mvisr')  INST_N=26;;
    'cris')   INST_N=27;;
    'cmis')   INST_N=28;;
    'viirs')  INST_N=29;;
    'windsat')INST_N=30;;
    'gifts')  INST_N=31;;
    'ssmt1')  INST_N=32;;
    'ssmt2')  INST_N=33;;
    'saphir') INST_N=34;;
    'madras') INST_N=35;;
    'ssmisz') INST_N=36;;
    'kavhrr') INST_N=37;;
    'iimager')INST_N=38;;
    'isoundr')INST_N=39;;
    'mwts')   INST_N=40;;
    'mwhs')   INST_N=41;;
    'iras')   INST_N=42;;
    'mwri')   INST_N=43;;
    'abi')    INST_N=44;;
    'mi')     INST_N=45;;
    'msumr')  INST_N=46;;
    'tansofts')INST_N=47;;
    'iir')    INST_N=48;;
    'mwr     ')INST_N=49;;
   *)        INST_N=-1;;
  esac

  case ${INST} in
    'msu' | 'amsua' | 'amsub' | 'tmi'  | 'ssmi' | 'ssmis'  | 'mwts' | 'mwri' \
          | 'hsb'   | 'mhs'   | 'cmis' | 'amsr' | 'atms'   | 'mwhs'  \
          | 'windsat'| 'ssmt1'| 'ssmt2'| 'saphir'| 'madras'| 'ssmisz'| 'mwr ' ) SENSOR_TYPE='mw';;
    'airs' | 'iasi' | 'cris' | 'gifts' | 'abi'  |'tansofts' ) SENSOR_TYPE='hi';;
    * ) SENSOR_TYPE='ir';;
  esac

export PLATFORM_N
export INST_N
export SENSOR_TYPE

}
